Stan Math Library: stan/math/fwd/scal/fun/log_inv_logit.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log_inv_logit.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_LOG_INV_LOGIT_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_LOG_INV_LOGIT_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/log_inv_logit.hpp>
7
8 namespace stan {
9
10 namespace math {
11
12 template <typename T>
13 inline
14 fvar<T>
15 log_inv_logit(const fvar<T>& x) {
16 using std::exp;
17 using stan::math::log_inv_logit;
18 return fvar<T>(log_inv_logit(x.val_),
19 x.d_ / (1 + exp(x.val_)));
20 }
21 }
22 }
23 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
log_inv_logit.hpp
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
stan::math::log_inv_logit
fvar< T > log_inv_logit(const fvar< T > &x)
Definition: log_inv_logit.hpp:15
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.